@@ -12,6 +12,94 @@ class Database:
     def __init__(self, authToken):
         self.authToken = authToken
 
+    ##################### start 2022 01 14 add (not in cmw git) ####################
+
+    def get_hk_earning_calendar(self, code):
+
+        link_url = 'http://www.hkfdb.net/data_api?'
+        token_str = 'token=' + str(self.authToken)
+        database_str = 'database=' + 'hk_earning_calendar'
+        code_str = 'code=' + code
+        link_str = link_url + code_str + '&' + token_str + '&' + database_str
+
+        print(link_str)
+        response = requests.get(link_str)
+        result = ast.literal_eval(json.loads(response.content))
+
+        df = pd.DataFrame(result)
+        df['datetime'] = pd.to_datetime(df['datetime'], format='%Y-%m-%d %H:%M:%S')
+        df = df.set_index(keys='datetime')
+        df = df.sort_index()
+
+        return df
+
+    def get_us_earning_calendar_by_date(self, start_date, end_date):
+
+        ### should change name to check_start_end_date ###
+        check_bool_dict = self.check_north_water_args(start_date, end_date)
+
+        if False not in list(check_bool_dict.values()):
+            # link_url = 'http://localhost:8000/data_api?'
+            link_url = 'http://www.hkfdb.net/data_api?'
+            token_str = 'token=' + str(self.authToken)
+            database_str = 'database=' + 'us_earning_calendar_by_date'
+            start_date_str = 'start_date=' + str(start_date)
+            end_date_str = 'end_date=' + str(end_date)
+            link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
+            print(link_str)
+            response = requests.get(link_str)
+            result = ast.literal_eval(json.loads(response.content))
+
+            df = pd.DataFrame(result)
+
+            df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
+
+            df = df.set_index(keys='date')
+            df = df.sort_index()
+            return df
+
+        else:
+            err_msg = 'Error in: '
+            for error in check_bool_dict:
+                if check_bool_dict[error] == False:
+                    err_msg += error + ','
+            print(err_msg)
+
+    def get_hk_earning_calendar_by_date(self, start_date, end_date):
+
+        ### should change name to check_start_end_date ###
+        check_bool_dict = self.check_north_water_args(start_date, end_date)
+
+        if False not in list(check_bool_dict.values()):
+            # link_url = 'http://localhost:8000/data_api?'
+            link_url = 'http://www.hkfdb.net/data_api?'
+            token_str = 'token=' + str(self.authToken)
+            database_str = 'database=' + 'hk_earning_calendar_by_date'
+            start_date_str = 'start_date=' + str(start_date)
+            end_date_str = 'end_date=' + str(end_date)
+            link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
+            print(link_str)
+            response = requests.get(link_str)
+            result = ast.literal_eval(json.loads(response.content))
+
+            df = pd.DataFrame(result)
+
+            df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d%H%M%S')
+
+            df = df.set_index(keys='datetime')
+            df = df[['code', 'name', 'result']]
+            df = df.sort_index()
+            return df
+
+        else:
+            err_msg = 'Error in: '
+            for error in check_bool_dict:
+                if check_bool_dict[error] == False:
+                    err_msg += error + ','
+            print(err_msg)
+
+    ##################### end 2022 01 14 add (not in cmw git) ####################
+
     def get_hk_stock_ohlc(self, code, start_date, end_date, freq, price_adj=False, vol_adj=False):
         # http://localhost:8000/api/cbbc_dis?sid=0910d3e18c01f86&token=efc220c6c6da52b&date=20210802&database=cbbc_dis
         # http://localhost:8000/data_api?sid=0910d3e18c01f86&token=efc220c6c6da52b&date=20210802&database=cbbc_dis
@@ -844,3 +932,5 @@ class Database:
                            'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
         return check_bool_dict
+
+
